@@ -434,6 +434,69 @@ func (c *PendingUpdatesView[K, V]) Iter(f func(k K, v V) IterAction) {
 	}
 }
 
+// IterBatched is like Iter but calls applyFn with batches of KVs to apply to
+// the dataplane. Iteration continues after errors, skipping over the
+// failed items. The applyFn function should return the number of items
+// successfully applied and an error if there was a problem applying any.
+//
+// When IterBatched returns an error, it means that at least one item
+// failed to be applied, but it returns number of items successfully applied.
+func (c *PendingUpdatesView[K, V]) IterBatched(applyFn func(k []K, v []V) (int, error)) {
+	batchSize := 128
+
+	ks := make([]K, 0, batchSize)
+	vs := make([]V, 0, batchSize)
+	count := 0
+
+	for k, v := range c.desiredUpdates {
+		ks = append(ks, k)
+		vs = append(vs, v)
+		count++
+
+		if count == batchSize {
+			applied, err := applyFn(ks, vs)
+			for i := 0; i < applied; i++ {
+				delete(c.desiredUpdates, ks[i])
+				c.inDataplaneAndDesired[ks[i]] = vs[i]
+			}
+
+			if err != nil {
+				applied++ // skip over the item that erred
+			}
+
+			count = batchSize - applied
+			if count == 0 {
+				if applied == batchSize {
+					ks = ks[:0]
+					vs = vs[:0]
+				} else {
+					ks = make([]K, 0, batchSize)
+					vs = make([]V, 0, batchSize)
+				}
+			} else {
+				ks = ks[applied:]
+				vs = vs[applied:]
+			}
+		}
+	}
+
+	for count > 0 {
+		applied, err := applyFn(ks, vs)
+		for i := 0; i < applied; i++ {
+			delete(c.desiredUpdates, ks[i])
+			c.inDataplaneAndDesired[ks[i]] = vs[i]
+		}
+
+		if err != nil {
+			applied++ // skip over the item that erred
+		}
+
+		ks = ks[applied:]
+		vs = vs[applied:]
+		count -= applied
+	}
+}
+
 func (c *PendingUpdatesView[K, V]) Len() int {
 	return len(c.desiredUpdates)
 }
@@ -470,6 +533,54 @@ func (c *PendingDeletionsView[K, V]) Iter(f func(k K) IterAction) {
 	}
 }
 
+func (c *PendingDeletionsView[K, V]) IterBatched(applyFn func(k []K) (int, error)) {
+	batchSize := 128
+
+	ks := make([]K, 0, batchSize)
+	count := 0
+
+	for k := range c.inDataplaneNotDesired {
+		ks = append(ks, k)
+		count++
+
+		if count == batchSize {
+			applied, err := applyFn(ks)
+			for i := 0; i < applied; i++ {
+				delete(c.inDataplaneNotDesired, ks[i])
+			}
+
+			if err != nil {
+				applied++ // skip over the item that erred
+			}
+
+			count -= applied
+			if count == 0 {
+				if applied == batchSize {
+					ks = ks[:0]
+				} else {
+					ks = make([]K, 0, batchSize)
+				}
+			} else {
+				ks = ks[applied:]
+			}
+		}
+	}
+
+	for count > 0 {
+		applied, err := applyFn(ks)
+		for i := 0; i < applied; i++ {
+			delete(c.inDataplaneNotDesired, ks[i])
+		}
+
+		if err != nil {
+			applied++ // skip over the item that erred
+		}
+
+		ks = ks[applied:]
+		count -= applied
+	}
+}
+
 func (c *PendingDeletionsView[K, V]) Len() int {
 	return len(c.inDataplaneNotDesired)
 }
